diff --git a/application/src/api/settings/actions/sendTestEmail.ts b/application/src/api/settings/actions/sendTestEmail.ts
index 5617cea..10200df 100644
--- a/application/src/api/settings/actions/sendTestEmail.ts
+++ b/application/src/api/settings/actions/sendTestEmail.ts
@@ -3,7 +3,7 @@ import { getAuthHeaders, getBaseUrl, validateEmail } from '../utils';
import { SettingsApiResponse } from '../types';
const createEmailTemplate = (template: string, data: any): { subject: string; htmlBody: string } => {
- let subject = 'Test Email from ReamStack';
+ let subject = 'Test Email from CheckCle';
let htmlBody = `
@@ -13,7 +13,7 @@ const createEmailTemplate = (template: string, data: any): { subject: string; ht
If you received this email, your SMTP configuration is working correctly.
- Sent from ReamStack Monitoring System
+ Sent from CheckCle Monitoring System
Template: ${template}
${data.collection ? `Collection: ${data.collection}` : ''}
@@ -24,7 +24,7 @@ const createEmailTemplate = (template: string, data: any): { subject: string; ht
switch (template) {
case 'verification':
- subject = 'Email Verification Test - ReamStack';
+ subject = 'Email Verification Test - CheckCle';
htmlBody = `
@@ -37,14 +37,14 @@ const createEmailTemplate = (template: string, data: any): { subject: string; ht
Collection: ${data.collection || '_superusers'}
- Sent from ReamStack Monitoring System
+ Sent from CheckCle Monitoring System
`;
break;
case 'password-reset':
- subject = 'Password Reset Test - ReamStack';
+ subject = 'Password Reset Test - CheckCle';
htmlBody = `
@@ -57,14 +57,14 @@ const createEmailTemplate = (template: string, data: any): { subject: string; ht
Collection: ${data.collection || '_superusers'}
- Sent from ReamStack Monitoring System
+ Sent from CheckCle Monitoring System
`;
break;
case 'email-change':
- subject = 'Email Change Confirmation Test - ReamStack';
+ subject = 'Email Change Confirmation Test - CheckCle';
htmlBody = `
@@ -76,7 +76,7 @@ const createEmailTemplate = (template: string, data: any): { subject: string; ht
Template: Email Change Confirmation
- Sent from ReamStack Monitoring System
+ Sent from CheckCle Monitoring System
@@ -178,10 +178,6 @@ export const sendTestEmail = async (data: any): Promise =>
smtpPort: smtpSettings.port || 587
});
- // For now, we'll simulate a successful email send
- // In a real implementation, you would integrate with your email service here
- // This could be nodemailer, SendGrid, or your PocketBase email system
-
// Simulate processing time
console.log('Simulating email send...');
await new Promise(resolve => setTimeout(resolve, 1000));
diff --git a/application/src/api/settings/actions/testEmail.ts b/application/src/api/settings/actions/testEmail.ts
index c3263aa..0557a86 100644
--- a/application/src/api/settings/actions/testEmail.ts
+++ b/application/src/api/settings/actions/testEmail.ts
@@ -2,7 +2,7 @@ import { getAuthHeaders, getBaseUrl, validateEmail } from '../utils';
import { SettingsApiResponse } from '../types';
const createEmailTemplate = (template: string, data: any): { subject: string; htmlBody: string } => {
- let subject = 'Test Email from ReamStack';
+ let subject = 'Test Email from CheckCle';
let htmlBody = `
@@ -12,7 +12,7 @@ const createEmailTemplate = (template: string, data: any): { subject: string; ht
If you received this email, your SMTP configuration is working correctly.
- Sent from ReamStack Monitoring System
+ Sent from CheckCle Monitoring System
Template: ${template}
${data.collection ? `Collection: ${data.collection}` : ''}
@@ -23,7 +23,7 @@ const createEmailTemplate = (template: string, data: any): { subject: string; ht
switch (template) {
case 'verification':
- subject = 'Email Verification Test - ReamStack';
+ subject = 'Email Verification Test - CheckCle';
htmlBody = `
@@ -36,14 +36,14 @@ const createEmailTemplate = (template: string, data: any): { subject: string; ht
Collection: ${data.collection || '_superusers'}
- Sent from ReamStack Monitoring System
+ Sent from CheckCle Monitoring System
`;
break;
case 'password-reset':
- subject = 'Password Reset Test - ReamStack';
+ subject = 'Password Reset Test - CheckCle';
htmlBody = `
@@ -56,14 +56,14 @@ const createEmailTemplate = (template: string, data: any): { subject: string; ht
Collection: ${data.collection || '_superusers'}
- Sent from ReamStack Monitoring System
+ Sent from CheckCle Monitoring System
`;
break;
case 'email-change':
- subject = 'Email Change Confirmation Test - ReamStack';
+ subject = 'Email Change Confirmation Test - CheckCle';
htmlBody = `
@@ -75,7 +75,7 @@ const createEmailTemplate = (template: string, data: any): { subject: string; ht
Template: Email Change Confirmation
- Sent from ReamStack Monitoring System
+ Sent from CheckCle Monitoring System
diff --git a/application/src/components/settings/about-system/AboutSystem.tsx b/application/src/components/settings/about-system/AboutSystem.tsx
index ae2ce8d..108cc32 100644
--- a/application/src/components/settings/about-system/AboutSystem.tsx
+++ b/application/src/components/settings/about-system/AboutSystem.tsx
@@ -83,7 +83,7 @@ export const AboutSystem: React.FC = () => {
{t('links')}
- {systemName || 'ReamStack'} {t('resources').toLowerCase()}
+ {systemName || 'CheckCle'} {t('resources').toLowerCase()}
diff --git a/application/src/services/incident/pdf/generator.ts b/application/src/services/incident/pdf/generator.ts
index 6337757..5ce2ffd 100644
--- a/application/src/services/incident/pdf/generator.ts
+++ b/application/src/services/incident/pdf/generator.ts
@@ -38,8 +38,8 @@ export const generatePdf = async (incident: IncidentItem): Promise => {
doc.setProperties({
title: title,
subject: 'Incident Report',
- author: 'ReamStack System',
- creator: 'ReamStack',
+ author: 'CheckCle System',
+ creator: 'CheckCle',
});
// Add header section
diff --git a/application/src/translations/types/about.ts b/application/src/translations/types/about.ts
index 244ec53..7197b39 100644
--- a/application/src/translations/types/about.ts
+++ b/application/src/translations/types/about.ts
@@ -1,6 +1,6 @@
export interface AboutTranslations {
- aboutReamStack: string;
+ aboutCheckCle: string;
systemDescription: string;
systemVersion: string;
license: string;
diff --git a/application/src/services/incident/pdf/headerFooter.ts b/application/src/services/incident/pdf/headerFooter.ts
index 9b3ff51..4e0c443 100644
--- a/application/src/services/incident/pdf/headerFooter.ts
+++ b/application/src/services/incident/pdf/headerFooter.ts
@@ -28,11 +28,11 @@ export const addHeader = (doc: jsPDF, incident: IncidentItem): number => {
doc.setFontSize(10);
doc.text(`Generated on: ${new Date().toLocaleDateString()}`, 105, yPos, { align: 'center' });
// Add ReamStack logo or text
yPos += 8;
doc.setFontSize(12);
doc.setFont(fonts.italic);
- doc.text('ReamStack Incident Management', 105, yPos, { align: 'center' });
+ doc.text('CheckCle Incident Management', 105, yPos, { align: 'center' });
// Add horizontal line
yPos += 5;
@@ -53,7 +53,7 @@ export const addFooter = (doc: jsPDF): void => {
doc.setFontSize(8);
doc.setTextColor(100, 100, 100);
doc.text(
- `Page ${i} of ${pageCount} | Generated by ReamStack Incident Management System`,
+ `Page ${i} of ${pageCount} | Generated by CheckCle Incident Management System`,
105,
285,
{ align: 'center' }
@@ -28,11 +28,11 @@ export const addHeader = (doc: jsPDF, incident: IncidentItem): number => {
doc.setFontSize(10);
doc.text(`Generated on: ${new Date().toLocaleDateString()}`, 105, yPos, { align: 'center' });
- // Add ReamStack logo or text
+ // Add CheckCle logo or text
yPos += 8;
doc.setFontSize(12);